@@ -1,7 +1,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
-#include "include/pmask.h"
+#include "headers/pmask.h"
 
 #ifdef USE_ALLEGRO
 #	include <allegro.h>
@@ -527,52 +527,6 @@ void pmask_load_pixels (struct PMASK *mask, void *pixels, int pitch, int bytes_p
 
 #endif
 
-#ifdef USE_SDL
-
-	static int SDL_getpixel(void *_surface, int x, int y)
-	{
-		int bpp = ((SDL_Surface*)_surface)->format->BytesPerPixel;
-		/* Here p is the address to the pixel we want to retrieve */
-		Uint8 *p = (Uint8 *)((SDL_Surface*)_surface)->pixels + y * ((SDL_Surface*)_surface)->pitch + x * bpp;
-
-		switch(bpp) {
-		case 1:
-			return *p;
-
-		case 2:
-			return *(Uint16 *)p;
-
-		case 3:
-#			if SDL_BYTEORDER == SDL_BIG_ENDIAN
-				return p[0] << 16 | p[1] << 8 | p[2];
-#			else
-				return p[0] | p[1] << 8 | p[2] << 16;
-#			endif
-		case 4:
-			return *(Uint32 *)p;
-
-		default:
-			return 0;       /* shouldn't happen, but avoids warnings */
-		}
-	}
-	static void load_sdl_pmask(PMASK *mask, SDL_Surface *sprite, int trans_color) {
-		pmask_load_func (mask, 0, 0, sprite, trans_color, SDL_getpixel);
-		return;
-	}
-	void init_sdl_pmask(struct PMASK *mask, struct SDL_Surface *sprite, int trans_color) {
-		init_pmask(mask, sprite->w, sprite->h);
-		load_sdl_pmask(mask, sprite, trans_color);
-		return;
-	}
-	PMASK *create_sdl_pmask(struct SDL_Surface *sprite, int trans_color) {
-		PMASK *ret;
-		ret = create_pmask(sprite->w, sprite->h);
-		if (!ret) return NULL;
-		load_sdl_pmask(ret, sprite, trans_color);
-		return ret;
-	}
-#endif
-
 
 int _check_pmask_collision(CONST struct PMASK *mask1, CONST struct PMASK *mask2, int dx, int dy1)
 {
