@@ -23,22 +23,27 @@
  */
  
 #include <allegro.h>
+#include <aldumb.h>
 
-#ifdef ALLEGRO_LINUX
 #include "config.h"
-#include "include/declare.h"
-#endif
-
-#ifndef ALLEGRO_LINUX
-#include "../include/declare.h"
-#endif
+#include "headers/declare.h"
 
 SAMPLE *shoot, *explode, *newhighscore, *screenshotsaved, *welcome;
-SAMPLE *letsgo, *gameisover;
-
-DUH *titlesong;
-DUH *gamesong;
-AL_DUH_PLAYER *gamesongplayer;
+SAMPLE *letsgo, *gameisover, *listhiscores;
 
 int music_volume;
 int sfx_volume;
+
+void check_if_hiscore_beaten(int passedscore, int passedhiscore)
+{
+	static bool hiscore_beaten=false;
+	
+	if(passedscore>passedhiscore)
+	{
+		if(!hiscore_beaten)
+		{
+			play_sample(newhighscore,sfx_volume,128,1000,0);
+			hiscore_beaten=true;
+		};
+	}
+}
